@@ -1,3 +1,6 @@
+// Copyright (c) 2023 Yuki Kimoto
+// MIT License
+
 #include "spvm_native.h"
 
 #include <assert.h>
@@ -28,7 +31,7 @@ int32_t SPVM__Sys__IO__FileStream__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
       int32_t status = fclose(fh);
       if (status == EOF) {
         env->die(env, stack, "[System Error]fclose failed:%s.", env->strerror(env, stack, errno, 0), __func__, FILE_NAME, __LINE__);
-        return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
+        return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
       }
       env->set_pointer(env, stack, obj_self, NULL);
     }
